==> modx-2.0.7-pl-ja.zip: modx-2.0.7-pl-ja/core/lexicon/ja/propertyset.inc.php <==
<?php
/**
 * Property Set Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['class_name'] = 'クラス名';
$_lang['default'] = '初期値';
$_lang['duplicate_of'] = '[[+name]]の複製';
$_lang['element_properties_desc'] = 'エレメントに対するプロパティの初期値を設定もしくは特定のプロパティセットの編集ができます。 <b>注</b>:もし初期値を編集した場合 When you edit the default set, you will be saving the properties to the default properties. Editing a specific property set will save those property settings to the property set.<br /><br />When you\'ve selected a property set to edit, the default properties will show in the grid in the color <span style="color: gray;">gray</span>. Properties in gray are not in the property set, but show up there for easier editing. Properties in <span style="color: green">green</span> are properties that have been overridden from the default. Properties in <span style="color: purple">purple</span> are new properties in the custom set that are not in the default properties.';
$_lang['file'] = 'ファイル';
$_lang['import'] = 'インポート';
$_lang['new_name'] = '新規名称';
$_lang['object'] = 'オブジェクト';
$_lang['properties'] = 'プロパティ';
$_lang['properties_default_locked'] = 'Default Properties Locked';
$_lang['properties_default_locked_msg'] = 'Only a user with the "unlock_element_properties" permission may unlock default properties.';
$_lang['properties_default_unlocked'] = 'Default Properties Unlocked';
$_lang['properties_import'] = 'Import Properties';
$_lang['properties_import_err_invalid'] = 'The file you specified is not a valid properties file. Please try again.';
$_lang['properties_import_err_upload'] = 'Please specify a valid properties file to upload.';
$_lang['properties_import_msg'] = 'Please select a valid properties file.';
$_lang['properties_remove'] = 'Remove Properties';
$_lang['properties_remove_confirm'] = 'Are you sure you want to remove these properties?';
$_lang['property_create'] = 'Create Property';
$_lang['property_update'] = 'Update Property';
$_lang['property_option_create'] = 'Create Property Option';
$_lang['property_option_remove'] = 'Remove Property Option';
$_lang['property_option_remove_confirm'] = 'Are you sure you want to remove this property option?';
$_lang['property_options'] = 'Property Options';
$_lang['property_revert'] = 'Revert Property to Default';
$_lang['property_revert_confirm'] = 'Are you sure you want to revert this property to the default?';
$_lang['property_revert_all'] = 'Revert All to Default';
$_lang['property_revert_all_confirm'] = 'Are you sure you want to revert all properties to their defaults?';
$_lang['property_remove'] = 'Remove Property';
$_lang['property_remove_confirm'] = 'Are you sure you want to remove this property?';
$_lang['propertyset'] = 'Property Set';
$_lang['propertyset_add'] = 'Add Property Set';
$_lang['propertyset_create'] = 'Create Property Set';
$_lang['propertyset_create_new'] = 'Create New Property Set';
$_lang['propertyset_duplicate'] = 'Duplicate Property Set';
$_lang['propertyset_duplicate_copyels'] = 'Copy Element associations?';
$_lang['propertyset_element_add'] = 'Attach Element to Property Set';
$_lang['propertyset_element_remove'] = 'Remove Element from Property Set';
$_lang['propertyset_element_remove_confirm'] = 'Are you sure you want to unattach this element from this property set?';
$_lang['propertyset_err_ae'] = 'A property set already exists with that name. Please specify another.';
$_lang['propertyset_err_associate'] = 'An error occurred while trying to associate the property set to the element.';
$_lang['propertyset_err_create'] = 'An error occurred while trying to create the property set.';
$_lang['propertyset_err_element_add'] = 'An error occurred while trying to add the element to the property set.';
$_lang['propertyset_err_element_nf'] = 'That element is not associated to that property set.';
$_lang['propertyset_err_element_remove'] = 'An error occurred while trying to remove the element from the property set.';
$_lang['propertyset_err_nf'] = 'Property set not found.';
$_lang['propertyset_err_nfs'] = 'Property set not found with ID [[+id]].';
$_lang['propertyset_err_ns'] = 'Property set not specified.';
$_lang['propertyset_err_ns_name'] = 'Please specify a name for the property set.';
$_lang['propertyset_err_remove'] = 'An error occurred while trying to remove the property set.';
$_lang['propertyset_err_update'] = 'An error occurred while trying to update the property set.';
$_lang['propertyset_new'] = 'New Property Set';
$_lang['propertyset_panel_desc'] = 'Here you can create a property set, or select an existing one to attach to this element.';
$_lang['propertyset_remove'] = 'Remove Property Set';
$_lang['propertyset_remove_confirm'] = 'Are you sure you want to remove this property set?';
$_lang['propertyset_save'] = 'Save Property Set';
$_lang['propertyset_update'] = 'Update Property Set';
$_lang['propertysets'] = 'Property Sets';
$_lang['propertysets_desc'] = 'Here you can manage your property sets. Click a set in the tree to load that set\'s properties into the grid, where you can modify them specifically. You can also right-click on property sets in the tree to attach or unattach elements for them.';

==> modx-2.1.2-pl-ja.zip: modx-2.1.2-pl-ja/core/lexicon/ja/propertyset.inc.php <==
<?php
/**
 * Property Set Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author Nick http://smallworld.west-tokyo.com
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['class_name'] = 'クラス名';
$_lang['default'] = '初期値';
$_lang['duplicate_of'] = '[[+name]]の複製';
$_lang['element_properties_desc'] = 'プロパティの初期値やプロパティセットの設定ができます。詳細についてはヘルプをご覧ください。<b>注</b>:もし初期値を編集した場合 When you edit the default set, you will be saving the properties to the default properties. Editing a specific property set will save those property settings to the property set.<br /><br />When you\'ve selected a property set to edit, the default properties will show in the grid in the color <span style="color: gray;">gray</span>. Properties in gray are not in the property set, but show up there for easier editing. Properties in <span style="color: green">green</span> are properties that have been overridden from the default. Properties in <span style="color: purple">purple</span> are new properties in the custom set that are not in the default properties.';
$_lang['file'] = 'ファイル';
$_lang['import'] = 'インポート';
$_lang['new_name'] = '新規名称';
$_lang['object'] = 'オブジェクト';
$_lang['properties'] = 'プロパティ';
$_lang['properties_default_locked'] = 'ロック';
$_lang['properties_default_locked_msg'] = 'Only a user with the "unlock_element_properties" permission may unlock default properties.';
$_lang['properties_default_unlocked'] = 'ロック';
$_lang['properties_import'] = 'インポート';
$_lang['properties_import_err_invalid'] = 'The file you specified is not a valid properties file. Please try again.';
$_lang['properties_import_err_upload'] = 'Please specify a valid properties file to upload.';
$_lang['properties_import_msg'] = 'Please select a valid properties file.';
$_lang['properties_remove'] = 'これらのプロパティを削除';
$_lang['properties_remove_confirm'] = 'Are you sure you want to remove these properties?';
$_lang['property_create'] = '新規作成';
$_lang['property_update'] = '編集';
$_lang['property_option_create'] = 'プロパティオプションを新規作成';
$_lang['property_option_remove'] = 'プロパティオプションを削除';
$_lang['property_option_remove_confirm'] = 'Are you sure you want to remove this property option?';
$_lang['property_options'] = 'プロパティオプション';
$_lang['property_revert'] = 'Revert Property to Default';
$_lang['property_revert_confirm'] = 'Are you sure you want to revert this property to the default?';
$_lang['property_revert_all'] = '全てデフォルトに戻す';
$_lang['property_revert_all_confirm'] = 'Are you sure you want to revert all properties to their defaults?';
$_lang['property_remove'] = '削除';
$_lang['property_remove_confirm'] = 'Are you sure you want to remove this property?';
$_lang['propertyset'] = 'プロパティセット';
$_lang['propertyset_add'] = 'プロパティセットを追加';
$_lang['propertyset_create'] = '新規作成';
$_lang['propertyset_create_new'] = 'プロパティセットを新規作成';
$_lang['propertyset_duplicate'] = '複製';
$_lang['propertyset_duplicate_copyels'] = 'Copy Element associations?';
$_lang['propertyset_element_add'] = 'エレメントを紐付ける';
$_lang['propertyset_element_remove'] = 'このエレメントを外す';
$_lang['propertyset_element_remove_confirm'] = 'Are you sure you want to unattach this element from this property set?';
$_lang['propertyset_err_ae'] = 'A property set already exists with that name. Please specify another.';
$_lang['propertyset_err_associate'] = 'An error occurred while trying to associate the property set to the element.';
$_lang['propertyset_err_create'] = 'An error occurred while trying to create the property set.';
$_lang['propertyset_err_element_add'] = 'An error occurred while trying to add the element to the property set.';
$_lang['propertyset_err_element_nf'] = 'That element is not associated to that property set.';
$_lang['propertyset_err_element_remove'] = 'An error occurred while trying to remove the element from the property set.';
$_lang['propertyset_err_nf'] = 'プロパティセットはありません。';
$_lang['propertyset_err_nfs'] = 'Property set not found with ID [[+id]].';
$_lang['propertyset_err_ns'] = 'Property set not specified.';
$_lang['propertyset_err_ns_name'] = 'Please specify a name for the property set.';
$_lang['propertyset_err_remove'] = 'An error occurred while trying to remove the property set.';
$_lang['propertyset_err_update'] = 'An error occurred while trying to update the property set.';
$_lang['propertyset_new'] = '新規作成';
$_lang['propertyset_panel_desc'] = 'Here you can create a property set, or select an existing one to attach to this element.';
$_lang['propertyset_remove'] = '削除';
$_lang['propertyset_remove_confirm'] = 'Are you sure you want to remove this property set?';
$_lang['propertyset_save'] = '保存';
$_lang['propertyset_update'] = '編集';
$_lang['propertysets'] = 'プロパティセットの管理';
$_lang['propertysets_desc'] = 'Here you can manage your property sets. Click a set in the tree to load that set\'s properties into the grid, where you can modify them specifically. You can also right-click on property sets in the tree to attach or unattach elements for them.';
